Login - The Something Awful Forums

## Forums Login

BAD PASSWORD!
The password you entered is wrong. Remember passwords are case-sensitive! Be careful... too many wrong passwords and you will be locked out temporarily. You've tried to login 1 times so far. Login with username and password:

Username: |
Password: |

Security pointers...

1. Use a UNIQUE password for your SA account!
2. Do NOT use the same password here as you use for other sites!
3. NEVER tell anyone your password (we will NEVER ask you for it)
4. Make sure the email address associated with your account is secure
5. Use a password that is complicated and nonsensical, like you
6. NEVER share your account with other jerks
7. When you are finished using the forums, logout
8. NEVER trust someone because they are a goon (unless they're really funny)

YOU are responsible for your own account security!
Lost or forgot your password? Click here.
Powered by: vBulletin Version 2.2.9 (SABB-v2.24.12)
Copyright ©2000, 2001, Jelsoft Enterprises Limited.
Copyright ©2024, Jeffrey of YOSPOS
Privacy Policy